import { GridOptions } from '@ag-grid-community/core';
import { CSSVarTokenMap } from '@genesislcap/foundation-ui';
/**
 * All official AG CSS variables
 * @public
 */
export declare enum AgGridCSSVars {
    foregroundColor = "--ag-foreground-color",
    dataColor = "--ag-data-color",
    secondaryForegroundColor = "--ag-secondary-foreground-color",
    headerForegroundColor = "--ag-header-foreground-color",
    disabledForegroundColor = "--ag-disabled-foreground-color",
    backgroundColor = "--ag-background-color",
    headerBackgroundColor = "--ag-header-background-color",
    subheaderBackgroundColor = "--ag-subheader-background-color",
    subheaderToolbarBackgroundColor = "--ag-subheader-toolbar-background-color",
    controlPanelBackgroundColor = "--ag-control-panel-background-color",
    selectedRowBackgroundColor = "--ag-selected-row-background-color",
    oddRowBackgroundColor = "--ag-odd-row-background-color",
    rowHoverColor = "--ag-row-hover-color",
    rangeSelectionBorderColor = "--ag-range-selection-border-color",
    rangeSelectionBackgroundColor = "--ag-range-selection-background-color",
    selectedTabUnderlineColor = "--ag-selected-tab-underline-color",
    rangeSelectionChartCategoryBackgroundColor = "--ag-range-selection-chart-category-background-color",
    rangeSelectionChartBackgroundColor = "--ag-range-selection-chart-background-color",
    headerCellHoverBackgroundColor = "--ag-header-cell-hover-background-color",
    headerCellMovingBackgroundColor = "--ag-header-cell-moving-background-color",
    chipBackgroundColor = "--ag-chip-background-color",
    borderColor = "--ag-border-color",
    secondaryBorderColor = "--ag-secondary-border-color",
    rowBorderColor = "--ag-row-border-color",
    headerColumnSeparatorColor = "--ag-header-column-separator-color",
    headerColumnResizeHandleColor = "--ag-header-column-resize-handle-color",
    inputBorderColor = "--ag-input-border-color",
    inputDisabledBorderColor = "--ag-input-disabled-border-color",
    inputDisabledBackgroundColor = "--ag-input-disabled-background-color",
    checkboxBackgroundColor = "--ag-checkbox-background-color",
    checkboxCheckedColor = "--ag-checkbox-checked-color",
    checkboxUncheckedColor = "--ag-checkbox-unchecked-color",
    checkboxIndeterminateColor = "--ag-checkbox-indeterminate-color",
    toggleButtonOffBorderColor = "--ag-toggle-button-off-border-color",
    toggleButtonOffBackgroundColor = "--ag-toggle-button-off-background-color",
    toggleButtonOnBorderColor = "--ag-toggle-button-on-border-color",
    toggleButtonOnBackgroundColor = "--ag-toggle-button-on-background-color",
    toggleButtonSwitchBackgroundColor = "--ag-toggle-button-switch-background-color",
    toggleButtonSwitchBorderColor = "--ag-toggle-button-switch-border-color",
    minichartSelectedChartColor = "--ag-minichart-selected-chart-color",
    minichartSelectedPageColor = "--ag-minichart-selected-page-color",
    modalOverlayBackgroundColor = "--ag-modal-overlay-background-color",
    inputFocusBoxShadow = "--ag-input-focus-box-shadow",
    inputFocusBorderColor = "--ag-input-focus-border-color"
}
/**
 * The available Grid Pro themes.
 * @public
 */
export declare enum AgGridTheme {
    alpine = "ag-theme-alpine",
    alpineDark = "ag-theme-alpine-dark",
    balham = "ag-theme-balham",
    balhamDark = "ag-theme-balham-dark",
    material = "ag-theme-material"
}
/**
 * Generates the class name for a given Grid Pro theme name.
 * @param themeName - the Grid Pro theme name
 * @returns the class name for the Grid Pro token map
 * @public
 * @example The result of this will be a class name that is applied to the grid part of GridPro template (actual content of the class comes from agThemeTokenMapCSS):
 * ```html
 * <span part="grid" class="ag-theme-genesis-rapid-dark">
 * ```
 */
export declare const agThemeTokenMapClassname: (themeName: string) => string;
/**
 * Generates the id name for custom Grid Pro fonts.
 * @param themeName - the Grid Pro theme name
 * @returns the id name for the Grid Pro fonts
 * @public
 * @example The result of this is used in the id of style tag:
 * ```html
 * <style id="ag-theme-alpine-fonts"></style>
 * ```
 */
export declare const agThemeFontsId: (themeName: string) => string;
/**
 * Generates the CSS for a given GridPro theme name and token map
 * @param themeName - the GridPro theme name
 * @param tokenMap - a map of CSS variables {@link @genesislcap/grid-pro#AgGridCSSVars} and custom token values
 * @returns the CSS for the Grid Pro token map
 * @public
 * @example
 * ```ts
 * export const agThemeGenesisRapidTokens = {
 *  backgroundColor: create<Swatch>('rapid-ag-background-color').withDefault((elem: HTMLElement) =>
 *    baseLayerLuminance.getValueFor(elem) === StandardLuminance.LightMode
 *      ? lightColors.backgroundSwatch
 *      : darkColors.backgroundSwatch
 *  ),
 *  foregroundColor: create<Swatch>('rapid-ag-foreground-color').withDefault((elem: HTMLElement) =>
 *    baseLayerLuminance.getValueFor(elem) === StandardLuminance.LightMode
 *      ? lightColors.foregroundSwatch
 *      : darkColors.foregroundSwatch
 *  ),
 * };
 * export const agThemeGenesisRapidTokenMap: CSSVarTokenMap<AgGridCSSVars | string> = {
 *  [AgGridCSSVars.backgroundColor]: agThemeGenesisRapidTokens.backgroundColor,
 *  [AgGridCSSVars.foregroundColor]: agThemeGenesisRapidTokens.foregroundColor,
 * };
 * ```
 */
export declare const agThemeTokenMapCSS: (themeName: string, tokenMap: CSSVarTokenMap<any>) => import("@microsoft/fast-element").ElementStyles;
/**
 * Grid Pro Components type, used to define the custom components that will be registered in the grid
 * @public
 */
export type GridComponents = {
    [componentName: string]: any;
};
/**
 * The available Grid Pro Renderer Types
 * @public
 */
export declare enum GridProRendererTypes {
    action = "action",
    actionsMenu = "actionsMenu",
    boolean = "boolean",
    editable = "editable",
    text = "text",
    select = "select",
    dateEditor = "dateEditor",
    selectEditor = "selectEditor",
    numberEditor = "numberEditor",
    stringEditor = "stringEditor",
    multiselectEditor = "multiselectEditor"
}
/**
 * Event fired when grid is ready
 * @public
 */
export declare const GRID_READY_EVENT = "onGridReady";
/**
 * Key used to store currently edited column when it being synced with server side data
 * @public
 */
export declare const EDITED_COLUMN_FIELD = "__editedColumn";
/**
 * Key used to store error details (column, message) when inline edit fails sync with server side data
 * @public
 */
export declare const ERROR_COLUMN_FIELD = "__errorColumn";
/**
 * Grid options config used to configure grids across the application
 * @public
 */
export interface GridOptionsConfig extends GridOptions {
}
/**
 * Default grid options
 * @public
 */
export declare const defaultGridOptionsConfig: GridOptionsConfig;
/**
 * Grid options config used to inject into grids in application
 * @internal
 */
export declare const GridOptionsConfig: import("@microsoft/fast-foundation").InterfaceSymbol<GridOptionsConfig>;
//# sourceMappingURL=grid-pro.types.d.ts.map